==> ejc-analysis-impl-3.0.0-20230711.063736-52-sources.jar: com/ejianc/business/analysis/vo/ProjectBusinessVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 中建科技项目商务策划分析管理报表
 * 
 * @author generator
 * 
 */
public class ProjectBusinessVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer projectStatus; // 项目状态
    private String reportingMonth; // 报表日期
    private Integer orgStatusOrder; // 二级组织排序
    private Date projectCreateTime; // 项目创建日期
    private BigDecimal realityMoney; // 实际完成产值（万元）
    private String businessFlag; // 编制商务策划书（是/否）
    private Integer approvalTotal; //累计立项（项）
    private BigDecimal predictMoney; // 策划预计创效金额（万元）
    private BigDecimal predictRatio; // 策划预计创效率（%）
    private Integer amount; // 数量（项）
    private BigDecimal planMoney; // 策划创效金额（万元）
    private BigDecimal planRatio; // 策划创效率（%）
    private String remark; // 备注
    private BigDecimal sumPlanCost;//累计实际成本
    private Integer setUpItem;//累计立项
    private BigDecimal  expectEffect;//预计创效
    private Integer implementItem; // 实施项(项)
    private BigDecimal planEffect;// 策划创效(万元)
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName; // 项目状态名称


    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public Integer getImplementItem() {
        return implementItem;
    }

    public void setImplementItem(Integer implementItem) {
        this.implementItem = implementItem;
    }

    public BigDecimal getPlanEffect() {
        return planEffect;
    }

    public void setPlanEffect(BigDecimal planEffect) {
        this.planEffect = planEffect;
    }

    public BigDecimal getExpectEffect() {
        return expectEffect;
    }

    public void setExpectEffect(BigDecimal expectEffect) {
        this.expectEffect = expectEffect;
    }

    public Integer getSetUpItem() {
        return setUpItem;
    }

    public void setSetUpItem(Integer setUpItem) {
        this.setUpItem = setUpItem;
    }

    public BigDecimal getSumPlanCost() {
        return sumPlanCost;
    }

    public void setSumPlanCost(BigDecimal sumPlanCost) {
        this.sumPlanCost = sumPlanCost;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public BigDecimal getRealityMoney() {
        return realityMoney;
    }

    public void setRealityMoney(BigDecimal realityMoney) {
        this.realityMoney = realityMoney;
    }
    public String getBusinessFlag() {
        return businessFlag;
    }

    public void setBusinessFlag(String businessFlag) {
        this.businessFlag = businessFlag;
    }
    public Integer getApprovalTotal() {
        return approvalTotal;
    }

    public void setApprovalTotal(Integer approvalTotal) {
        this.approvalTotal = approvalTotal;
    }
    public BigDecimal getPredictMoney() {
        return predictMoney;
    }

    public void setPredictMoney(BigDecimal predictMoney) {
        this.predictMoney = predictMoney;
    }
    public BigDecimal getPredictRatio() {
        return predictRatio;
    }

    public void setPredictRatio(BigDecimal predictRatio) {
        this.predictRatio = predictRatio;
    }
    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }
    public BigDecimal getPlanMoney() {
        return planMoney;
    }

    public void setPlanMoney(BigDecimal planMoney) {
        this.planMoney = planMoney;
    }
    public BigDecimal getPlanRatio() {
        return planRatio;
    }

    public void setPlanRatio(BigDecimal planRatio) {
        this.planRatio = planRatio;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}

==> ejc-analysis-impl-3.0.0-20241017.064316-257-sources.jar: com/ejianc/business/analysis/vo/ProjectBusinessVO.java <==
package com.ejianc.business.analysis.vo;

import java.util.Date;
import java.math.*;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 中建科技项目商务策划分析管理报表
 * 
 * @author generator
 * 
 */
public class ProjectBusinessVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long orgId; // 所属组织id
    private String orgCode; // 所属组织编码
    private String orgName; // 所属组织名称
    private Long projectDepartmentId; // 项目部id
    private Long twoOrgId; // 二级组织id
    private String twoOrgCode; // 二级组织编码
    private String twoOrgName; // 二级组织名称
    private Long projectId; // 项目id
    private String projectCode; // 项目编码
    private String projectName; // 项目名称
    private Integer projectStatus; // 项目状态
    private String reportingMonth; // 报表日期
    private Integer orgStatusOrder; // 二级组织排序
    private Date projectCreateTime; // 项目创建日期
    private BigDecimal realityMoney; // 实际完成产值（万元）
    private String businessFlag; // 编制商务策划书（是/否）
    private Integer approvalTotal; //累计立项（项）
    private BigDecimal predictMoney; // 策划预计创效金额（万元）
    private BigDecimal predictRatio; // 策划预计创效率（%）
    private Integer amount; // 数量（项）
    private BigDecimal planMoney; // 策划创效金额（万元）
    private BigDecimal planRatio; // 策划创效率（%）
    private String remark; // 备注
    private BigDecimal sumPlanCost;//累计实际成本
    private Integer setUpItem;//累计立项
    private BigDecimal  expectEffect;//预计创效
    private Integer implementItem; // 实施项(项)
    private BigDecimal planEffect;// 策划创效(万元)
    private String number; // 序号
    private Integer projectStatusOrder; // 项目状态排序
    private String projectStatusName; // 项目状态名称
    private BigDecimal oneselfContract; // 自施合同额（万元）

    public BigDecimal getOneselfContract() {
        return oneselfContract;
    }

    public void setOneselfContract(BigDecimal oneselfContract) {
        this.oneselfContract = oneselfContract;
    }

    public String getNumber() {
        return number;
    }

    public void setNumber(String number) {
        this.number = number;
    }

    public Integer getProjectStatusOrder() {
        return projectStatusOrder;
    }

    public void setProjectStatusOrder(Integer projectStatusOrder) {
        this.projectStatusOrder = projectStatusOrder;
    }

    public String getProjectStatusName() {
        return projectStatusName;
    }

    public void setProjectStatusName(String projectStatusName) {
        this.projectStatusName = projectStatusName;
    }

    public Integer getImplementItem() {
        return implementItem;
    }

    public void setImplementItem(Integer implementItem) {
        this.implementItem = implementItem;
    }

    public BigDecimal getPlanEffect() {
        return planEffect;
    }

    public void setPlanEffect(BigDecimal planEffect) {
        this.planEffect = planEffect;
    }

    public BigDecimal getExpectEffect() {
        return expectEffect;
    }

    public void setExpectEffect(BigDecimal expectEffect) {
        this.expectEffect = expectEffect;
    }

    public Integer getSetUpItem() {
        return setUpItem;
    }

    public void setSetUpItem(Integer setUpItem) {
        this.setUpItem = setUpItem;
    }

    public BigDecimal getSumPlanCost() {
        return sumPlanCost;
    }

    public void setSumPlanCost(BigDecimal sumPlanCost) {
        this.sumPlanCost = sumPlanCost;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public Long getTwoOrgId() {
        return twoOrgId;
    }

    public void setTwoOrgId(Long twoOrgId) {
        this.twoOrgId = twoOrgId;
    }
    public String getTwoOrgCode() {
        return twoOrgCode;
    }

    public void setTwoOrgCode(String twoOrgCode) {
        this.twoOrgCode = twoOrgCode;
    }
    public String getTwoOrgName() {
        return twoOrgName;
    }

    public void setTwoOrgName(String twoOrgName) {
        this.twoOrgName = twoOrgName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Integer getProjectStatus() {
        return projectStatus;
    }

    public void setProjectStatus(Integer projectStatus) {
        this.projectStatus = projectStatus;
    }
    public String getReportingMonth() {
        return reportingMonth;
    }

    public void setReportingMonth(String reportingMonth) {
        this.reportingMonth = reportingMonth;
    }
    public Integer getOrgStatusOrder() {
        return orgStatusOrder;
    }

    public void setOrgStatusOrder(Integer orgStatusOrder) {
        this.orgStatusOrder = orgStatusOrder;
    }
    public Date getProjectCreateTime() {
        return projectCreateTime;
    }

    public void setProjectCreateTime(Date projectCreateTime) {
        this.projectCreateTime = projectCreateTime;
    }
    public BigDecimal getRealityMoney() {
        return realityMoney;
    }

    public void setRealityMoney(BigDecimal realityMoney) {
        this.realityMoney = realityMoney;
    }
    public String getBusinessFlag() {
        return businessFlag;
    }

    public void setBusinessFlag(String businessFlag) {
        this.businessFlag = businessFlag;
    }
    public Integer getApprovalTotal() {
        return approvalTotal;
    }

    public void setApprovalTotal(Integer approvalTotal) {
        this.approvalTotal = approvalTotal;
    }
    public BigDecimal getPredictMoney() {
        return predictMoney;
    }

    public void setPredictMoney(BigDecimal predictMoney) {
        this.predictMoney = predictMoney;
    }
    public BigDecimal getPredictRatio() {
        return predictRatio;
    }

    public void setPredictRatio(BigDecimal predictRatio) {
        this.predictRatio = predictRatio;
    }
    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }
    public BigDecimal getPlanMoney() {
        return planMoney;
    }

    public void setPlanMoney(BigDecimal planMoney) {
        this.planMoney = planMoney;
    }
    public BigDecimal getPlanRatio() {
        return planRatio;
    }

    public void setPlanRatio(BigDecimal planRatio) {
        this.planRatio = planRatio;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
}
